@@ -5,10 +5,10 @@
 #define WIDGET_H
 
 #include <QtGui/QLabel>
-#include <QNetworkConfigurationManager>
-#include <QSharedPointer>
 
-QTM_USE_NAMESPACE
+#include <QSharedPointer>
+#include <QMouseEvent>
+//QTM_USE_NAMESPACE
 
 class EveCharacter;
 class EveSettingsDialog;
@@ -19,6 +19,11 @@ class EveModel;
 class Widget : public QLabel
 {
     Q_OBJECT
+    enum TrainingState {
+        QueueEmpty, // <! No items in training queue
+        QueuePartial, // <! The queue still has room
+        QueueFull // <! The queue is full
+    };
 
 public:
     Widget(QWidget *parent = 0);
@@ -32,13 +37,17 @@ public slots:
     void onlineStateChanged(bool online);
     void loadTraining();
     void trainingLoaded();
+    virtual void mousePressEvent ( QMouseEvent * event );
+    virtual void mouseReleaseEvent ( QMouseEvent * event );
 private:
     EveSettingsDialog *m_settings;
     EveSkillTraining *m_training;
-    QNetworkConfigurationManager *m_net;
+    //QNetworkConfigurationManager *m_net;
     SkillTree *m_skills;
     QSharedPointer<EveModel> m_model;
     QTimer *m_timer;
+    QTimer *m_updateTimer;
+    bool m_pressed;
 };
 
 #endif // WIDGET_H
